@@ -174,7 +174,8 @@ Uses cached version if available to avoid repeated process calls."
                 (setq-local exec-path path)
                 (when (= 0 (process-file aidermacs-program nil t nil "--version"))
                   (goto-char (point-min))
-                  (when (re-search-forward "aider \\([0-9]+\\.[0-9]+\\.[0-9]+\\)" nil t)
+                  (when (re-search-forward
+                         (concat aidermacs-program " \\([0-9]+\\.[0-9]+\\.[0-9]+\\)") nil t)
                     (match-string 1)))))))
   (message "Aider version %s" aidermacs--cached-version)
   aidermacs--cached-version)
